//  File: ConvertTemperatures.java
//  Enhanced version of temperature conversion
//  New components include Buttons and a Scrollbar.
// The Scrollbar and input box must work together

import java.awt.*;
import java.awt.event.*;

class ConvertTemperatures extends Frame
  implements ActionListener, WindowListener, AdjustmentListener

{ Label directions;
  TextField fahrenheit;
  Label celsius;
  Scrollbar tempGuage;
  Button Compute,Quit;
  
  
  ConvertTemperatures(String s)
  { super(s);
    setSize(300,200);
    // setLayout(new FlowLayout());   No LayoutManager. Place items manually
    addWindowListener(this);
    // Add Label for Directions
    directions = new Label("Enter temperature in Fahrenheit:");
    directions.setBounds(10,30,160,20);
    add(directions);
    // Add TextField for inputting temperatures
    fahrenheit = new TextField(2);
    fahrenheit.setText("68");
    fahrenheit.setBounds(200,30,40,20);  // Set location in frame and size
    add(fahrenheit);
    fahrenheit.addActionListener(this);
    // Add a Scrollbar as an alternative input source. (Lots of events can happen...)
    tempGuage=new Scrollbar(Scrollbar.HORIZONTAL,68,1,-500,500);
    tempGuage.setLocation(5,80);
    tempGuage.setBounds(5,55,250,20);
    tempGuage.setUnitIncrement(10);
    tempGuage.setBlockIncrement(25);
    tempGuage.setVisibleAmount(5);
    add(tempGuage);
    tempGuage.addAdjustmentListener(this);
    // Add buttons to compute and quit
    Compute=new Button("Compute!");
    Compute.setBounds(200,140,70,20);
    add(Compute);
    Compute.addActionListener(this);
    Quit=new Button("Quit");
    Quit.setBounds(200,165,70,20);
    add(Quit);
    Quit.addActionListener(this);
    // Add label for reporting output
    celsius = new Label();
    celsius.setBounds(10,85,250,30);
    celsius.setFont(new Font("TimesRoman 12 point bold.", 20, 20));
    add(celsius);
    setVisible(true);
  }

  public void windowClosed(WindowEvent event) {}
  public void windowDeiconified(WindowEvent event) {}
  public void windowIconified(WindowEvent event) {}
  public void windowActivated(WindowEvent event) {}
  public void windowDeactivated(WindowEvent event) {}
  public void windowOpened(WindowEvent event) {}
  public void windowClosing(WindowEvent event) { System.exit(0); }

  // Handle action events:
  //	TextField return pressed
  //	Button pushed
  public void actionPerformed(ActionEvent event)
  { int f = Integer.parseInt(fahrenheit.getText());
    // Set the Scrollbar to show the temperature in the TextField box
    tempGuage.setValue(f);
    if (event.getActionCommand()=="Compute!") {
	    	long c = Math.round(5.0*(f - 32)/9.0);
	    	celsius.setText(f + "\u00B0F = " + c + "\u00B0C");
    }
    else if (event.getActionCommand()=="Quit")
		System.exit(0);
    else   // Clear off the last result
		celsius.setText("                       ");
  }
  
  // Handle Adjustment events on the Scrollbar:
  //	Arrows, gray area or position indicator
  public void adjustmentValueChanged(AdjustmentEvent event)
  {if (event.getAdjustmentType()==event.UNIT_DECREMENT) {
		int value=Integer.valueOf(fahrenheit.getText()).intValue();
		int decValue=tempGuage.getUnitIncrement();
		if (value-decValue>tempGuage.getMinimum())
			fahrenheit.setText(String.valueOf(value-decValue));
		else {
			tempGuage.setValue(tempGuage.getMinimum());
			fahrenheit.setText(String.valueOf(tempGuage.getValue()));
		}
   }
   else if (event.getAdjustmentType()==event.UNIT_INCREMENT) {
		int value=Integer.valueOf(fahrenheit.getText()).intValue();
		int incValue=tempGuage.getUnitIncrement();
		if (value+incValue<tempGuage.getMaximum())
			fahrenheit.setText(String.valueOf(value+incValue));
		else {
			tempGuage.setValue(tempGuage.getMaximum());
			fahrenheit.setText(String.valueOf(tempGuage.getValue()));
		}
   }
   else if (event.getAdjustmentType()==event.BLOCK_DECREMENT) {
		int value=Integer.valueOf(fahrenheit.getText()).intValue();
		int decValue=tempGuage.getBlockIncrement();
		if (value-decValue>tempGuage.getMinimum())
			fahrenheit.setText(String.valueOf(value-decValue));
		else {
			tempGuage.setValue(tempGuage.getMinimum());
			fahrenheit.setText(String.valueOf(tempGuage.getValue()));
		}
   }
   else if (event.getAdjustmentType()==event.BLOCK_INCREMENT) {
		int value=Integer.valueOf(fahrenheit.getText()).intValue();
		int incValue=tempGuage.getBlockIncrement();
		if (value+incValue<tempGuage.getMaximum())
			fahrenheit.setText(String.valueOf(value+incValue));
		else {
			tempGuage.setValue(tempGuage.getMaximum());
			fahrenheit.setText(String.valueOf(tempGuage.getValue()));
		}
   }
   else if (event.getAdjustmentType()==5)  // Adjusted scroll box
		fahrenheit.setText(String.valueOf(tempGuage.getValue()));
   tempGuage.setValue(Integer.valueOf(fahrenheit.getText()).intValue());
   celsius.setText("                                     ");
  }

}

class TestConvertTemperatures
{ public static void main(String[] args)
  { new ConvertTemperatures("Fahrenheit To Celsius Conversion");
  }
}
